@@ -1,18 +1,7 @@
 # -*- coding: utf-8 -*-
+# SPDX-FileCopyrightText: 2011 Sybren A. Stüvel <sybren@stuvel.eu>
 #
-#  Copyright 2011 Sybren A. Stüvel <sybren@stuvel.eu>
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#      https://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 """Functions for PKCS#1 version 1.5 encryption and signing
 
@@ -234,8 +223,8 @@ def decrypt(crypto, priv_key):
     # Find the 00 separator between the padding and the message
     try:
         sep_idx = cleartext.index(b"\x00", 2)
-    except ValueError:
-        raise DecryptionError("Decryption failed")
+    except ValueError as err:
+        raise DecryptionError("Decryption failed") from err
 
     return cleartext[sep_idx + 1 :]
 
